/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*                       DIRECCIN DE PRUEBAS Y MEDICIN
/*                           SUBDIRECCION DE ANLISIS
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                     SEXTO GRADO DE PRIMARIA (Excale 06)
/*
/*                         **** CIENCIAS NATURALES ****
/*
/*                     Ciclo escolar evaluado: 2008 - 2009
/*_____________________________________________________________________________
/*
/*
/*  PROGRAMA PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE CIENCIAS NATURALES
/*                               EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale06_2009_Alum_CN.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale06_2009_Alum_CN.txt
/*         as como el archivo Excale06_2009_Alum_CN.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale06_2009_Alum_CN.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale06_2009_Alum_CN.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Subdireccin de Anlisis del Instituto
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 1082
/*      Domicilio: Jos Ma. Velasco No. 101. 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 20 DE ABRIL DE 2012
/*
/*  ****************************************************************************/

LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale06_2009_Alum_CN.TXT";

PROC FORMAT;
     VALUE id_entF     1         ="Aguascalientes"
                       2         ="Baja California"
                       3         ="Baja California Sur"
                       4         ="Campeche"
                       5         ="Coahuila"
                       6         ="Colima"
                       7         ="Chiapas"
                       8         ="Chihuahua"
                       9         ="Distrito Federal"
                       10        ="Durango"
                       11        ="Guanajuato"
                       12        ="Guerrero"
                       13        ="Hidalgo"
                       14        ="Jalisco"
                       15        ="Mxico"
                       16        ="Michoacn"
                       17        ="Morelos"
                       18        ="Nayarit"
                       19        ="Nuevo Len"
                       20        ="Oaxaca"
                       21        ="Puebla"
                       22        ="Quertaro"
                       23        ="Quintana Roo"
                       24        ="San Luis Potos"
                       25        ="Sinaloa"
                       26        ="Sonora"
                       27        ="Tabasco"
                       28        ="Tamaulipas"
                       29        ="Tlaxcala"
                       30        ="Veracruz"
                       31        ="Yucatn"
                       32        ="Zacatecas";
     VALUE id_modF     1         ="Urbana Pblica"
                       2         ="Rural Pblica"
                       3         ="Educacin Indgena"
                       4         ="Curso Comunitario"
                       5         ="Privada"
                       6         ="General"
                       7         ="Tcnica"
                       8         ="Telesecundaria"
                       9         ="Privada";
     VALUE $modF       "UP"      ="Urbano Pblico"
                       "RP"      ="Rural Pblico"
                       "EI"      ="Educacin Indgena"
                       "CC"      ="Cursos Comunitarios"
                       "UPV"     ="Privados"
                       "GRAL"    ="General"
                       "TEC"     ="Tcnica"
                       "TV"      ="Telesecundaria"
                       "PRIV"    ="Privada";
     VALUE $gmF        "1"       ="Muy alto"
                       "2"       ="Alto"
                       "3"       ="Medio"
                       "4"       ="Bajo"
                       "5"       ="Muy bajo"
                       "9"       ="Perdido"
                       "NA"      ="No aplica";
     VALUE marg_urF    1         ="Alta marginacin"
                       2         ="Baja marginacin"
                       7         ="No aplica";
     VALUE sexoF       1         ="Hombre"
                       2         ="Mujer"
                       8         ="Respuesta mltiple"
                       9         ="Respuesta omitida";
     VALUE edadF       99        ="Respuesta omitida";
     VALUE edadcF      1         ="Once aos o menos"
                       2         ="Doce aos"
                       3         ="Trece aos"
                       4         ="Catorce aos o ms"
                       9         ="Respuesta omitida";
     VALUE edadnF      1         ="Edad normativa"
                       2         ="Extra-edad"
                       9         ="Respuesta omitida";
     VALUE edad_acF    10        ="10 aos"
                       11        ="11 aos"
                       12        ="12 aos"
                       13        ="13 aos"
                       14        ="14 aos"
                       15        ="15 aos o ms"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE mes_nacF    1         ="Enero"
                       2         ="Febrero"
                       3         ="Marzo"
                       4         ="Abril"
                       5         ="Mayo"
                       6         ="Junio"
                       7         ="Julio"
                       8         ="Agosto"
                       9         ="Septiembre"
                       10        ="Octubre"
                       11        ="Noviembre"
                       12        ="Diciembre"
                       98        ="Respuesta mltiple"
                       99        ="Respuesta omitida";
     VALUE docenteF    99999     ="Respuesta omitida";
     VALUE na1_d17F    0         ="Fallo"
                       1         ="Acierto"
                       5         ="Reactivo no alcanzado (se considera como no administrado)"
                       6         ="Reactivo no administrado por error de impresin"
                       7         ="Reactivo no administrado (No se incluy en su cuadernillo de examen)";
RUN;



DATA INEE.Excale06_2009_Alum_CN;
   LENGTH
       NACIONAL           3
       ESCUELA            4
       ID_ENT             3
       NOM_ENT            $19
       ID_MOD             3
       MOD                $4
       GM                 $2
       MARG_URB           3
       ESTRATO            $7
       ENTEST             $6
       ALUMNO             6
       ID_INSTR           $16
       SEXO               3
       EDAD               8
       EDADC              3
       EDADN              3
       EDAD_AC            3
       MES_NAC            3
       W_ALU              8
       DOCENTE            5
       PNA_01             3
       PNA_02             3
       PNA_03             3
       PNA_04             3
       PNA_05             3
       PNA_06             3
       PNA_07             3
       PNA_08             3
       PNA_09             3
       PNA_10             3
       PNA_11             3
       PNA_12             3
       PNA_14             3
       PNA_16             3
       PNA_17             3
       PNA_18             3
       PNB_01             3
       PNB_02             3
       PNB_03             3
       PNB_04             3
       PNB_05             3
       PNB_06             3
       PNB_07             3
       PNB_08             3
       PNB_09             3
       PNB_10             3
       PNB_11             3
       PNB_12             3
       PNB_13             3
       PNB_14             3
       PNB_15             3
       PNB_16             3
       PNB_17             3
       PNB_18             3
       PNC_01             3
       PNC_02             3
       PNC_03             3
       PNC_04             3
       PNC_05             3
       PNC_06             3
       PNC_07             3
       PNC_08             3
       PNC_09             3
       PNC_10             3
       PNC_11             3
       PNC_12             3
       PNC_13             3
       PNC_14             3
       PNC_15             3
       PNC_16             3
       PNC_17             3
       PNC_18             3
       PND_01             3
       PND_02             3
       PND_03             3
       PND_04             3
       PND_06             3
       PND_07             3
       PND_08             3
       PND_09             3
       PND_10             3
       PND_11             3
       PND_12             3
       PND_13             3
       PND_14             3
       PND_15             3
       PND_16             3
       PND_17             3
       PV1CNA             8
       PV2CNA             8
       PV3CNA             8
       PV4CNA             8
       PV5CNA             8
       CNANVL1            3
       CNANVL2            3
       CNANVL3            3
       CNANVL4            3
       CNANVL5            3
       CNANVBL1           3
       CNANVBL2           3
       CNANVBL3           3
       CNANVBL4           3
       CNANVBL5           3
       WVARSTRR           3
       W_FSTR1            8
       W_FSTR2            8
       W_FSTR3            8
       W_FSTR4            8
       W_FSTR5            8
       W_FSTR6            8
       W_FSTR7            8
       W_FSTR8            8
       W_FSTR9            8
       W_FSTR10           8
       W_FSTR11           8
       W_FSTR12           8
       W_FSTR13           8
       W_FSTR14           8
       W_FSTR15           8
       W_FSTR16           8
       W_FSTR17           8
       W_FSTR18           8
       W_FSTR19           8
       W_FSTR20           8
       W_FSTR21           8
       W_FSTR22           8
       W_FSTR23           8
       W_FSTR24           8
       W_FSTR25           8
       W_FSTR26           8
       W_FSTR27           8
       W_FSTR28           8
       W_FSTR29           8
       W_FSTR30           8
       W_FSTR31           8
       W_FSTR32           8
       W_FSTR33           8
       W_FSTR34           8
       W_FSTR35           8
       W_FSTR36           8
       W_FSTR37           8
       W_FSTR38           8
       W_FSTR39           8
       W_FSTR40           8
       W_FSTR41           8
       W_FSTR42           8
       W_FSTR43           8
       W_FSTR44           8
       W_FSTR45           8
       W_FSTR46           8
       W_FSTR47           8
       W_FSTR48           8
       W_FSTR49           8
       W_FSTR50           8
       W_FSTR51           8
       W_FSTR52           8
       W_FSTR53           8
       W_FSTR54           8
       W_FSTR55           8
       W_FSTR56           8
       W_FSTR57           8
       W_FSTR58           8
       W_FSTR59           8
       W_FSTR60           8
       W_FSTR61           8
       W_FSTR62           8
       W_FSTR63           8
       W_FSTR64           8
       W_FSTR65           8
       W_FSTR66           8
       W_FSTR67           8
       W_FSTR68           8
       W_FSTR69           8
       W_FSTR70           8
       W_FSTR71           8
       W_FSTR72           8
       W_FSTR73           8
       W_FSTR74           8
       W_FSTR75           8
       W_FSTR76           8
       W_FSTR77           8
       W_FSTR78           8
       W_FSTR79           8
       W_FSTR80           8
 ;

INFILE alum MISSOVER LINESIZE = 1103;
   INPUT
       NACIONAL          1 - 1
       ESCUELA           2 - 5
       ID_ENT            6 - 7
       NOM_ENT           8 - 26
       ID_MOD           27 - 27
       MOD              28 - 31
       GM               32 - 33
       MARG_URB         34 - 34
       ESTRATO          35 - 41
       ENTEST           42 - 47
       ALUMNO           48 - 53
       ID_INSTR         54 - 69
       SEXO             70 - 70
       EDAD             71 - 81
       EDADC            82 - 82
       EDADN            83 - 83
       EDAD_AC          84 - 85
       MES_NAC          86 - 87
       W_ALU            88 - 98
       DOCENTE          99 - 103
       PNA_01          104 - 104
       PNA_02          105 - 105
       PNA_03          106 - 106
       PNA_04          107 - 107
       PNA_05          108 - 108
       PNA_06          109 - 109
       PNA_07          110 - 110
       PNA_08          111 - 111
       PNA_09          112 - 112
       PNA_10          113 - 113
       PNA_11          114 - 114
       PNA_12          115 - 115
       PNA_14          116 - 116
       PNA_16          117 - 117
       PNA_17          118 - 118
       PNA_18          119 - 119
       PNB_01          120 - 120
       PNB_02          121 - 121
       PNB_03          122 - 122
       PNB_04          123 - 123
       PNB_05          124 - 124
       PNB_06          125 - 125
       PNB_07          126 - 126
       PNB_08          127 - 127
       PNB_09          128 - 128
       PNB_10          129 - 129
       PNB_11          130 - 130
       PNB_12          131 - 131
       PNB_13          132 - 132
       PNB_14          133 - 133
       PNB_15          134 - 134
       PNB_16          135 - 135
       PNB_17          136 - 136
       PNB_18          137 - 137
       PNC_01          138 - 138
       PNC_02          139 - 139
       PNC_03          140 - 140
       PNC_04          141 - 141
       PNC_05          142 - 142
       PNC_06          143 - 143
       PNC_07          144 - 144
       PNC_08          145 - 145
       PNC_09          146 - 146
       PNC_10          147 - 147
       PNC_11          148 - 148
       PNC_12          149 - 149
       PNC_13          150 - 150
       PNC_14          151 - 151
       PNC_15          152 - 152
       PNC_16          153 - 153
       PNC_17          154 - 154
       PNC_18          155 - 155
       PND_01          156 - 156
       PND_02          157 - 157
       PND_03          158 - 158
       PND_04          159 - 159
       PND_06          160 - 160
       PND_07          161 - 161
       PND_08          162 - 162
       PND_09          163 - 163
       PND_10          164 - 164
       PND_11          165 - 165
       PND_12          166 - 166
       PND_13          167 - 167
       PND_14          168 - 168
       PND_15          169 - 169
       PND_16          170 - 170
       PND_17          171 - 171
       PV1CNA          172 - 179
       PV2CNA          180 - 187
       PV3CNA          188 - 195
       PV4CNA          196 - 203
       PV5CNA          204 - 211
       CNANVL1         212 - 212
       CNANVL2         213 - 213
       CNANVL3         214 - 214
       CNANVL4         215 - 215
       CNANVL5         216 - 216
       CNANVBL1        217 - 217
       CNANVBL2        218 - 218
       CNANVBL3        219 - 219
       CNANVBL4        220 - 220
       CNANVBL5        221 - 221
       WVARSTRR        222 - 223
       W_FSTR1         224 - 234
       W_FSTR2         235 - 245
       W_FSTR3         246 - 256
       W_FSTR4         257 - 267
       W_FSTR5         268 - 278
       W_FSTR6         279 - 289
       W_FSTR7         290 - 300
       W_FSTR8         301 - 311
       W_FSTR9         312 - 322
       W_FSTR10        323 - 333
       W_FSTR11        334 - 344
       W_FSTR12        345 - 355
       W_FSTR13        356 - 366
       W_FSTR14        367 - 377
       W_FSTR15        378 - 388
       W_FSTR16        389 - 399
       W_FSTR17        400 - 410
       W_FSTR18        411 - 421
       W_FSTR19        422 - 432
       W_FSTR20        433 - 443
       W_FSTR21        444 - 454
       W_FSTR22        455 - 465
       W_FSTR23        466 - 476
       W_FSTR24        477 - 487
       W_FSTR25        488 - 498
       W_FSTR26        499 - 509
       W_FSTR27        510 - 520
       W_FSTR28        521 - 531
       W_FSTR29        532 - 542
       W_FSTR30        543 - 553
       W_FSTR31        554 - 564
       W_FSTR32        565 - 575
       W_FSTR33        576 - 586
       W_FSTR34        587 - 597
       W_FSTR35        598 - 608
       W_FSTR36        609 - 619
       W_FSTR37        620 - 630
       W_FSTR38        631 - 641
       W_FSTR39        642 - 652
       W_FSTR40        653 - 663
       W_FSTR41        664 - 674
       W_FSTR42        675 - 685
       W_FSTR43        686 - 696
       W_FSTR44        697 - 707
       W_FSTR45        708 - 718
       W_FSTR46        719 - 729
       W_FSTR47        730 - 740
       W_FSTR48        741 - 751
       W_FSTR49        752 - 762
       W_FSTR50        763 - 773
       W_FSTR51        774 - 784
       W_FSTR52        785 - 795
       W_FSTR53        796 - 806
       W_FSTR54        807 - 817
       W_FSTR55        818 - 828
       W_FSTR56        829 - 839
       W_FSTR57        840 - 850
       W_FSTR58        851 - 861
       W_FSTR59        862 - 872
       W_FSTR60        873 - 883
       W_FSTR61        884 - 894
       W_FSTR62        895 - 905
       W_FSTR63        906 - 916
       W_FSTR64        917 - 927
       W_FSTR65        928 - 938
       W_FSTR66        939 - 949
       W_FSTR67        950 - 960
       W_FSTR68        961 - 971
       W_FSTR69        972 - 982
       W_FSTR70        983 - 993
       W_FSTR71        994 - 1004
       W_FSTR72       1005 - 1015
       W_FSTR73       1016 - 1026
       W_FSTR74       1027 - 1037
       W_FSTR75       1038 - 1048
       W_FSTR76       1049 - 1059
       W_FSTR77       1060 - 1070
       W_FSTR78       1071 - 1081
       W_FSTR79       1082 - 1092
       W_FSTR80       1093 - 1103
;

   LABEL
       NACIONAL    = "Variable auxiliar para obtener promedios nacionales"
       ESCUELA     = "Identificador de la escuela"
       ID_ENT      = "Entidad federativa (identificador numrico)"
       NOM_ENT     = "Entidad federativa"
       ID_MOD      = "Estrato escolar o Modalidad educativa (identificador numrico)"
       MOD         = "Estrato escolar o Modalidad educativa"
       GM          = "Clave de Grado de Marginacin Urbano oficial/Rural (AGEB/localidad)"
       MARG_URB    = "Marginalidad Urbana"
       ESTRATO     = "Estrato de muestreo. Se construy con ENTIDAD, MODALIDAD Y MARGINALIDAD. No es comn a todas las tablas pues en algunos casos se colapsaron registros"
       ENTEST      = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
       ALUMNO      = "Identificador del alumno"
       ID_INSTR    = "Identificador del cuadernillo de examen"
       SEXO        = "Sexo del alumno"
       EDAD        = "Edad del alumno al mes de mayo de 2009, en aos (al momento de la aplicacin)"
       EDADC       = "Edad del alumno al mes de mayo de 2009, codificada (al momento de la aplicacin)"
       EDADN       = "Edad normativa"
       EDAD_AC     = "Edad en aos cumplidos (al momento de la aplicacin)"
       MES_NAC     = "Mes de nacimiento del alumno (al momento de la aplicacin)"
       W_ALU       = "Peso muestral o ponderador del alumno"
       DOCENTE     = "Identificador del docente que imparte clases al alumno"
       PNA_01      = "Reactivo 57. Distinguir el fsil ms antiguo con base en su ubicacin en las capas de la Tierra."
       PNA_02      = "Reactivo 19. Reconocer la evolucin del ser humano."
       PNA_03      = "Reactivo 65. Identificar la aplicacin de algunas de las ideas de Darwin sobre la evolucin."
       PNA_04      = "Reactivo 28. Relacionar el inicio de la menstruacin con la posibilidad de que una mujer se embarace."
       PNA_05      = "Reactivo 13. Identificar la vacunacin como una accin adecuada para prevenir algunas enfermedades."
       PNA_06      = "Reactivo 4. Identificar la forma ms adecuada de actuar ante el riesgo de abuso sexual."
       PNA_07      = "Reactivo 35. Identificar un ejemplo de equidad de gnero en la familia."
       PNA_08      = "Reactivo 46. Identificar un rasgo fsico comn a una familia."
       PNA_09      = "Reactivo 27. Identificar actitudes de aprecio y respeto hacia una persona con discapacidad."
       PNA_10      = "Reactivo 24. Identificar un comportamiento correcto hacia una persona que vive con VIH."
       PNA_11      = "Reactivo 23. Reconocer una consecuencia derivada de un desastre natural."
       PNA_12      = "Reactivo 58. Identificar una aplicacin tecnolgica que favorezcan la produccin de alimentos."
       PNA_14      = "Reactivo 41. Identificar una actitud responsable ante el uso de los recursos naturales."
       PNA_16      = "Reactivo 63. Distinguir un modelo que represente mejor la expansin del Universo."
       PNA_17      = "Reactivo 49. Reconocer la explicacin acerca de cmo se form el planeta Tierra."
       PNA_18      = "Reactivo 22. Distinguir las semejanzas y diferencias de algunas mquinas simples."
       PNB_01      = "Reactivo 62. Identificar una representacin de la evolucin de los seres vivos."
       PNB_02      = "Reactivo 29. Identificar las implicaciones de la extincin de los seres vivos."
       PNB_03      = "Reactivo 1. Distinguir una adaptacin en una poblacin de seres vivos."
       PNB_04      = "Reactivo 15. Reconocer a los adultos mayores como personas con experiencia y sabidura."
       PNB_05      = "Reactivo 21. Identificar una actitud de solidaridad hacia los adultos mayores."
       PNB_06      = "Reactivo 54. Identificar un ejemplo de cmo influyen las telenovelas en la conducta de las personas."
       PNB_07      = "Reactivo 43. Reconocer la combinacin de cromosomas sexuales que corresponde a una mujer."
       PNB_08      = "Reactivo 32. Reconocer la relacin que existe entre el  aparato circulatorio y el sistema nervioso en un ejemplo."
       PNB_09      = "Reactivo 25. Identificar una medida bsica de primeros auxilios ante una quemadura."
       PNB_10      = "Reactivo 18. Distinguir los daos que puede causar el consumo de bebidas alcohlicas."
       PNB_11      = "Reactivo 56. Identificar una medida bsica de primeros auxilios ante la ingestin de sustancias txicas."
       PNB_12      = "Reactivo 31. Identificar una accin que contribuya a disminuir el impacto de la poblacin en los ecosistemas."
       PNB_13      = "Reactivo 59. Identificar cmo se puede reducir la generacin de basura en la escuela."
       PNB_14      = "Reactivo 26. Identificar medidas de prevencin ante los huracanes."
       PNB_15      = "Reactivo 68. Identificar un invento desarrollado con base en la palanca."
       PNB_16      = "Reactivo 33. Identificar la rapidez de los medios de transporte como resultado del uso de la tecnologa."
       PNB_17      = "Reactivo 37. Identificar el plano inclinado  en el que se requiere menor esfuerzo para subir."
       PNB_18      = "Reactivo 11. Reconocer la contribucin de uno de los grandes inventos al desarrollo de la humanidad."
       PNC_01      = "Reactivo 42. Identificar un organismo y su relacin con los factores fsicos de un ecosistema."
       PNC_02      = "Reactivo 48. Reconocer que los fsiles ayudan a conocer a los organismos que vivieron en el pasado."
       PNC_03      = "Reactivo 66. Reconocer las caractersticas que distinguen al ser humano de otros primates."
       PNC_04      = "Reactivo 12. Identificar una imagen que muestre un carcter sexual secundario."
       PNC_05      = "Reactivo 9. Identificar una medida de prevencin ante animales venenosos."
       PNC_06      = "Reactivo 44. Distinguir una actitud de respeto hacia personas de distintas culturas."
       PNC_07      = "Reactivo 17. Distinguir una actitud que favorezca la autoestima de las personas."
       PNC_08      = "Reactivo 2. Reconocer que la herencia biolgica y la alimentacin influyen en las caractersticas fsicas de las personas."
       PNC_09      = "Reactivo 30. Identificar la causa ms probable de una enfermedad del aparato digestivo."
       PNC_10      = "Reactivo 16. Reconocer una consecuencia del consumo de bebidas alcohlicas."
       PNC_11      = "Reactivo 61. Identificar la influencia de los medios de comunicacin en los hbitos alimentarios."
       PNC_12      = "Reactivo 51. Interpretar los datos ms elementales de una pirmide poblacional."
       PNC_13      = "Reactivo 8. Identificar una accin que mejor contribuya a solucionar el problema de la acumulacin de basura."
       PNC_14      = "Reactivo 47. Reconocer que el empleo de productos del desarrollo tecnolgico puede tener ventajas y desventajas."
       PNC_15      = "Reactivo 14. Identificar que la combustin produce gran cantidad de dixido de carbono."
       PNC_16      = "Reactivo 34. Identificar la aplicacin de una mquina simple."
       PNC_17      = "Reactivo 64. Identificar el funcionamiento de palancas con diferente punto de apoyo."
       PNC_18      = "Reactivo 7. Identificar la utilidad de las ruedas para facilitar el transporte de una carga."
       PND_01      = "Reactivo 60. Distinguir un factor biolgico en una imagen que representa un ecosistema."
       PND_02      = "Reactivo 67. Reconocer que los seres vivos tienen un ancestro comn."
       PND_03      = "Reactivo 45. Relacionar los cambios de los seres vivos y de los ecosistemas a lo largo de miles de aos."
       PND_04      = "Reactivo 53. Identificar una caracterstica propia del desarrollo de la infancia."
       PND_06      = "Reactivo 36. Identificar el proceso de la fecundacin."
       PND_07      = "Reactivo 5. Reconocer las desventajas de un embarazo en la adolescencia."
       PND_08      = "Reactivo 40. Reconocer el dolor y el ardor como manifestaciones del funcionamiento del sistema nervioso."
       PND_09      = "Reactivo 55. Distinguir una accin adecuada para prevenir alteraciones del organismo."
       PND_10      = "Reactivo 20. Identificar un padecimiento que se puede desarrollar por fumar."
       PND_11      = "Reactivo 50. Reconocer algunas de las demandas bsicas que se derivan del crecimiento poblacional."
       PND_12      = "Reactivo 3. Identificar una actividad humana que produce contaminacin."
       PND_13      = "Reactivo 38. Identificar una accin que promueva la disminucin de la contaminacin."
       PND_14      = "Reactivo 10. Reconocer el tiempo de renovacin de los recursos naturales."
       PND_15      = "Reactivo 52. Identificar la observacin de constelaciones como un referente para la elaboracin de calendarios en la antigedad."
       PND_16      = "Reactivo 39. Reconocer que los materiales de una erupcin ayudan a conocer la composicin de las capas de la Tierra."
       PND_17      = "Reactivo 6. Distinguir un avance tecnolgico y su aplicacin en una situacin cotidiana."
       PV1CNA      = "Primer valor plausible de Ciencias Naturales"
       PV2CNA      = "Segundo valor plausible de Ciencias Naturales"
       PV3CNA      = "Tercer valor plausible de Ciencias Naturales"
       PV4CNA      = "Cuarto valor plausible de Ciencias Naturales"
       PV5CNA      = "Quinto valor plausible de Ciencias Naturales"
       CNANVL1     = "Nivel de logro en Ciencias Naturales. Asociado a PV1CNA. (Cuatro niveles)"
       CNANVL2     = "Nivel de logro en Ciencias Naturales. Asociado a PV2CNA. (Cuatro niveles)"
       CNANVL3     = "Nivel de logro en Ciencias Naturales. Asociado a PV3CNA. (Cuatro niveles)"
       CNANVL4     = "Nivel de logro en Ciencias Naturales. Asociado a PV4CNA. (Cuatro niveles)"
       CNANVL5     = "Nivel de logro en Ciencias Naturales. Asociado a PV5CNA. (Cuatro niveles)"
       CNANVBL1    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Ciencias Naturales. Asociado a PV1CNA."
       CNANVBL2    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Ciencias Naturales. Asociado a PV2CNA."
       CNANVBL3    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Ciencias Naturales. Asociado a PV3CNA."
       CNANVBL4    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Ciencias Naturales. Asociado a PV4CNA."
       CNANVBL5    = "Identifica si el alumno pertenece al menos al nivel bsico de logro en Ciencias Naturales. Asociado a PV5CNA."
       WVARSTRR    = "Identificador del pseudoestrato (1 a 80) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
       W_FSTR1     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR2     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR3     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR4     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR5     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR6     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR7     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR8     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR9     = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR10    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR11    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR12    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR13    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR14    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR15    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR16    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR17    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR18    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR19    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR20    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR21    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR22    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR23    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR24    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR25    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR26    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR27    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR28    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR29    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR30    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR31    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR32    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR33    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR34    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR35    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR36    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR37    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR38    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR39    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR40    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR41    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR42    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR43    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR44    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR45    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR46    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR47    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR48    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR49    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR50    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR51    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR52    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR53    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR54    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR55    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR56    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR57    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR58    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR59    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR60    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR61    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR62    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR63    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR64    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR65    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR66    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR67    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR68    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR69    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR70    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR71    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR72    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR73    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR74    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR75    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR76    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR77    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR78    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR79    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
       W_FSTR80    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
;

   FORMAT
       NACIONAL           1.
       ESCUELA            4.
       ID_ENT             id_entF.
       NOM_ENT            $char19.
       ID_MOD             id_modF.
       MOD                $modF.
       GM                 $gmF.
       MARG_URB           marg_urF.
       ESTRATO            $char7.
       ENTEST             $char6.
       ALUMNO             5.
       ID_INSTR           $char16.
       SEXO               sexoF.
       EDAD               edadF.
       EDADC              edadcF.
       EDADN              edadnF.
       EDAD_AC            edad_acF.
       MES_NAC            mes_nacF.
       DOCENTE            docenteF.
       PNA_01             na1_d17F.
       PNA_02             na1_d17F.
       PNA_03             na1_d17F.
       PNA_04             na1_d17F.
       PNA_05             na1_d17F.
       PNA_06             na1_d17F.
       PNA_07             na1_d17F.
       PNA_08             na1_d17F.
       PNA_09             na1_d17F.
       PNA_10             na1_d17F.
       PNA_11             na1_d17F.
       PNA_12             na1_d17F.
       PNA_14             na1_d17F.
       PNA_16             na1_d17F.
       PNA_17             na1_d17F.
       PNA_18             na1_d17F.
       PNB_01             na1_d17F.
       PNB_02             na1_d17F.
       PNB_03             na1_d17F.
       PNB_04             na1_d17F.
       PNB_05             na1_d17F.
       PNB_06             na1_d17F.
       PNB_07             na1_d17F.
       PNB_08             na1_d17F.
       PNB_09             na1_d17F.
       PNB_10             na1_d17F.
       PNB_11             na1_d17F.
       PNB_12             na1_d17F.
       PNB_13             na1_d17F.
       PNB_14             na1_d17F.
       PNB_15             na1_d17F.
       PNB_16             na1_d17F.
       PNB_17             na1_d17F.
       PNB_18             na1_d17F.
       PNC_01             na1_d17F.
       PNC_02             na1_d17F.
       PNC_03             na1_d17F.
       PNC_04             na1_d17F.
       PNC_05             na1_d17F.
       PNC_06             na1_d17F.
       PNC_07             na1_d17F.
       PNC_08             na1_d17F.
       PNC_09             na1_d17F.
       PNC_10             na1_d17F.
       PNC_11             na1_d17F.
       PNC_12             na1_d17F.
       PNC_13             na1_d17F.
       PNC_14             na1_d17F.
       PNC_15             na1_d17F.
       PNC_16             na1_d17F.
       PNC_17             na1_d17F.
       PNC_18             na1_d17F.
       PND_01             na1_d17F.
       PND_02             na1_d17F.
       PND_03             na1_d17F.
       PND_04             na1_d17F.
       PND_06             na1_d17F.
       PND_07             na1_d17F.
       PND_08             na1_d17F.
       PND_09             na1_d17F.
       PND_10             na1_d17F.
       PND_11             na1_d17F.
       PND_12             na1_d17F.
       PND_13             na1_d17F.
       PND_14             na1_d17F.
       PND_15             na1_d17F.
       PND_16             na1_d17F.
       PND_17             na1_d17F.
       WVARSTRR           2.
   ;

/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
   IF  sexo = 8 THEN  sexo = .M;
   IF  edad_ac = 98 THEN  edad_ac = .M;
   IF  mes_nac = 98 THEN  mes_nac = .M;
   IF  GM = "9"  THEN  GM = .S;
   IF  GM = "NA"  THEN  GM = .S;
   IF  marg_urb = 7 THEN  marg_urb = .S;

   ARRAY perdidos1(3)  sexo edadc edadn;
   DO  i=1 TO 3;
         IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
   END;

   ARRAY perdidos2(3)  edad edad_ac mes_nac;
   DO  i=1 TO 3;
         IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
   END;

   IF  docente = 99999 THEN  docente = .S;

   ARRAY perdidos3(68)
                  PNA_01 PNA_02 PNA_03 PNA_04 PNA_05 PNA_06 PNA_07 PNA_08 PNA_09 PNA_10
                  PNA_11 PNA_12 PNA_14 PNA_16 PNA_17 PNA_18 PNB_01 PNB_02 PNB_03 PNB_04
                  PNB_05 PNB_06 PNB_07 PNB_08 PNB_09 PNB_10 PNB_11 PNB_12 PNB_13 PNB_14
                  PNB_15 PNB_16 PNB_17 PNB_18 PNC_01 PNC_02 PNC_03 PNC_04 PNC_05 PNC_06
                  PNC_07 PNC_08 PNC_09 PNC_10 PNC_11 PNC_12 PNC_13 PNC_14 PNC_15 PNC_16
                  PNC_17 PNC_18 PND_01 PND_02 PND_03 PND_04 PND_06 PND_07 PND_08 PND_09
                  PND_10 PND_11 PND_12 PND_13 PND_14 PND_15 PND_16 PND_17;

   DO  i=1 TO 68;
          IF perdidos3{i} = 5   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 6   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 7   THEN  perdidos3{i} = .N;
          IF perdidos3{i} = 8   THEN  perdidos3{i} = .M;
          IF perdidos3{i} = 9   THEN  perdidos3{i} = .S;
   END;

   drop i;
RUN;
